@@ -13,6 +13,7 @@ from .Frames import *
 from .Root import *
 from .Widgets import *
 from .base import *
+from ..Enumerations import EventType
 from ..Events import *
 from ..HID_BUFFER import HID_BUFFER
 
@@ -20,10 +21,10 @@ from ..HID_BUFFER import HID_BUFFER
 
 
 __all__ = [
-        'KeyboardMixin', 'KeyBoardState',
-        'PopupKeyboard', 'Placement', 'PlacementSet',
-        'value_title_mixin', 'BaseFramed', 'BaseFramedKeyboard', 'BaseTitled', 'BaseTitledKeyboard',
-        ]
+    'KeyboardMixin', 'KeyBoardState',
+    'PopupKeyboard', 'Placement', 'PlacementSet',
+    'value_title_mixin', 'BaseFramed', 'BaseFramedKeyboard', 'BaseTitled', 'BaseTitledKeyboard',
+    ]
 
 
 
@@ -53,7 +54,7 @@ class PlacementSet(object):
 
     def __repr__(self): return repr(self._state)
 
-
+# ------------------------------------------------------------------------------------------
 
 class PopupKeyboard(tkTopLevel):
     """
@@ -323,7 +324,7 @@ class KeyboardMixin:
         class KeyboardEntry(Entry, KeyboardMixin):
             def __init__(self, master, *,
                          root: tkRoot,
-                         placement: PlacementSet = PlacementSet(Placement.Auto),
+                         placement: PlacementSet = PlacementSet(PlacePosition.Auto),
                          keysize: int = None,
                          keycolor: str = None,
                          insertbackground: str = 'red',
@@ -333,7 +334,7 @@ class KeyboardMixin:
                          insertwidth: int = 3,
                          text: str = '',
                          Override_var: tk.StringVar = None,
-                         Color: dict = None, **kwargs):
+                         Color: Dict[str, str] = None, **kwargs):
                 Entry.__init__(self, master,
                                text=text,
                                Override_var=Override_var,
@@ -462,54 +463,7 @@ class KeyboardMixin:
     @property
     def popup_relheight(self) -> Optional[int]: return int(self.__root.height * self._popup_relheight) if self._popup_relheight is not None else None
 
-
-
-
-# _T = TypeVar('_T')
-# class KeyBaordTestFrame(Frame, Generic[_T]):
-#     @staticmethod
-#     def test():
-#         from .Themed import NotebookThemed
-#         from .KeyboardEntry import TitledKeyboardEntry, FramedKeyboardEntry  # circular import
-#         from .KeyboardComboBoxThemed import TitledKeyboardComboBoxThemed, FramedKeyboardComboBoxThemed  # circular import
-#         root = tkRoot(Screen_Width=800, Screen_Height=480, x=200, y=200)
-#         nb = NotebookThemed(root).PlaceFull()
-#         d = KeyBaordTestFrame.FrameConfig()
-#
-#         w = FramedKeyboardEntry.TEST(nb, root, d)
-#         nb.Add(w, title='Frame_Entry')
-#         w = TitledKeyboardEntry.TEST(nb, root, d)
-#         nb.Add(w, title='Titled_Entry')
-#
-#         w = FramedKeyboardComboBoxThemed.TEST(nb, root, d)
-#         nb.Add(w, title='Framed_COMBO_BOX')
-#         w = TitledKeyboardComboBoxThemed.TEST(nb, root, d)
-#         nb.Add(w, title='Titled_COMBO_BOX')
-#
-#         root.mainloop()
-#     @staticmethod
-#     def FrameConfig(): return {
-#             'Center_Below': dict(placement=PlacementSet(Placement.Center, Placement.Bottom)),
-#             'Left_Below':   dict(placement=PlacementSet(Placement.Left, Placement.Bottom)),
-#             'Right_Below':  dict(placement=PlacementSet(Placement.Right, Placement.Bottom)),
-#             'Auto_Below':   dict(placement=PlacementSet(Placement.Auto, Placement.Bottom)),
-#             'FULL_Auto':    { },
-#             'Center_Above': dict(placement=PlacementSet(Placement.Center, Placement.Top)),
-#             'Left_Above':   dict(placement=PlacementSet(Placement.Left, Placement.Top)),
-#             'Right_Above':  dict(placement=PlacementSet(Placement.Right, Placement.Top)),
-#             'Auto_Above':   dict(placement=PlacementSet(Placement.Auto, Placement.Top)),
-#             }
-#     Center_Below: _T
-#     Left_Below: _T
-#     Right_Below: _T
-#     Auto_Below: _T
-#     FULL_Auto: _T
-#     Center_Above: _T
-#     Left_Above: _T
-#     Right_Above: _T
-#     Auto_Above: _T
-#
-#     def iter(self) -> List[_T]: return [getattr(self, key) for key in self.FrameConfig().keys()]
+# ------------------------------------------------------------------------------------------
 
 class value_title_mixin:
     Title: Label
@@ -542,6 +496,7 @@ class value_title_mixin:
         if isinstance(value, str): return dict(text=value)
         return value
 
+# ------------------------------------------------------------------------------------------
 
 class BaseTitled(Frame, value_title_mixin):
     """
@@ -572,7 +527,7 @@ class BaseTitled(Frame, value_title_mixin):
         self.Entry = cls(self, **value_kwargs).Grid(row=1, column=0, padx=RowPadding, pady=RowPadding)
 
     # @classmethod
-    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[Placement, str, int]]], frame_bg: str = 'light blue'):
+    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[PlacePosition, str, int]]], frame_bg: str = 'light blue'):
     #     frame: KeyBaordTestFrame[cls] = KeyBaordTestFrame(master, background=frame_bg)
     #     for key, value in d.items():
     #         w = cls(frame, title=key, **value).PackHorizontal()
@@ -607,7 +562,7 @@ class BaseTitledKeyboard(Frame, value_title_mixin):
         self.Entry = cls(self, root=root, **value_kwargs).Grid(row=1, column=0, padx=RowPadding, pady=RowPadding)
 
     # @classmethod
-    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[Placement, str, int]]], frame_bg: str = 'light blue'):
+    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[PlacePosition, str, int]]], frame_bg: str = 'light blue'):
     #     frame: KeyBaordTestFrame[cls] = KeyBaordTestFrame(master, background=frame_bg)
     #     for key, value in d.items():
     #         w = cls(frame, root=root, title=key, **value).PackHorizontal()
@@ -615,7 +570,7 @@ class BaseTitledKeyboard(Frame, value_title_mixin):
     #
     #     return frame
 
-
+# ------------------------------------------------------------------------------------------
 
 class BaseFramed(LabelFrame, value_title_mixin):
     """
@@ -646,7 +601,7 @@ class BaseFramed(LabelFrame, value_title_mixin):
     def title(self, value: str): self.txt = value
 
     # @classmethod
-    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[Placement, str, int]]], frame_bg: str = 'light blue'):
+    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[PlacePosition, str, int]]], frame_bg: str = 'light blue'):
     #     frame: KeyBaordTestFrame[cls] = KeyBaordTestFrame(master, background=frame_bg)
     #     for key, value in d.items():
     #         w = cls(frame, title=key, **value).PackHorizontal()
@@ -681,7 +636,7 @@ class BaseFramedKeyboard(LabelFrame, value_title_mixin):
     def title(self, value: str): self.txt = value
 
     # @classmethod
-    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[Placement, str, int]]], frame_bg: str = 'light blue'):
+    # def TEST(cls, master, root: tkRoot, d: Dict[str, Dict[str, Union[PlacePosition, str, int]]], frame_bg: str = 'light blue'):
     #     frame: KeyBaordTestFrame[cls] = KeyBaordTestFrame(master, background=frame_bg)
     #     for key, value in d.items():
     #         w = cls(frame, root=root, title=key, **value).PackHorizontal()
