@@ -9,10 +9,10 @@ from PythonExtensions.debug import *
 def Test_base():
     start = Point.Create(0, 0)
     end = Point.Create(150, 150)
-    pic_pos = Point.Create(10, 10)
+    pic_pos = PlacePosition.Create(10, 10)
     img_size = Size.Create(200, 200)
 
-    print(CropBox.Box(start, end, pic_pos, img_size))
+    print(CropBox.Box(start=start, end=end, pic=pic_pos, img=img_size))
 
 
 
